📖 API reference
---------------

Preprocessing
~~~~~~~~~~~~~

.. module:: delnx.pp
.. currentmodule:: delnx.pp
.. autosummary::
    :toctree: genapi

    pseudobulk
    size_factors
    dispersion

Differential Expression
~~~~~~~~~~~~~~~~~~~~~~
.. module:: delnx.tl
.. currentmodule:: delnx.tl
.. autosummary::
    :toctree: genapi

    de

Models
~~~~~~
.. module:: delnx.models
.. currentmodule:: delnx.models
.. autosummary::
    :toctree: genapi

    LinearRegression
    LogisticRegression
    NegativeBinomialRegression
    DispersionEstimator
